.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_DISCONNECT" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_disconnect \- close a connection to the server

.SH SYNOPSIS
.sp
.nf
pg_disconnect \fIconn\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_disconnect\fR closes a connection to the
PostgreSQL server.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of the connection to be closed.
.SH "RETURN VALUE"
.PP
None
