.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_copytupledesc" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_copytupledesc \- make a copy of a row descriptor in the upper executor context

.SH SYNOPSIS
.sp
.nf
TupleDesc SPI_copytupledesc(TupleDesc \fItupdesc\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_copytupledesc\fR makes a copy of a row
descriptor in the upper executor context.
.SH "ARGUMENTS"
.TP
\fBTupleDesc \fItupdesc\fB\fR
row descriptor to be copied
.SH "RETURN VALUE"
.PP
the copied row descriptor; \fBNULL\fR only if
\fItupdesc\fR is \fBNULL\fR
