.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ALTER SCHEMA" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ALTER SCHEMA \- change the definition of a schema

.SH SYNOPSIS
.sp
.nf
ALTER SCHEMA \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBALTER SCHEMA\fR changes the definition of a schema.
The only functionality is to rename the schema. To rename a schema
you must own the schema and have the privilege
CREATE for the database.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
Name of a schema
.TP
\fB\fInewname\fB\fR
The new name of the schema
.SH "COMPATIBILITY"
.PP
There is no \fBALTER SCHEMA\fR statement in the SQL
standard.
.SH "SEE ALSO"
CREATE SCHEMA [\fBcreate_schema\fR(l)], DROP SCHEMA [\fBdrop_schema\fR(l)]
