.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_EXPORT" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_export \- export a large object to a file

.SH SYNOPSIS
.sp
.nf
pg_lo_export \fIconn\fR \fIloid\fR \fIfilename\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_export\fR writes the specified large object
into a file.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which the large object
exists.
.TP
\fB\fIloid\fB\fR
The OID of the large object.
.TP
\fB\fIfilename\fB\fR
Specifies the file into which the data is to be exported.
.SH "RETURN VALUE"
.PP
None
.SH "NOTES"
.PP
\fBpg_lo_export\fR must be called within a
\fBBEGIN\fR/\fBCOMMIT\fR transaction block.
