.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ALTER LANGUAGE" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ALTER LANGUAGE \- change the definition of a procedural language

.SH SYNOPSIS
.sp
.nf
ALTER LANGUAGE \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBALTER LANGUAGE\fR changes the definition of a
language. The only functionality is to rename the language. Only
a superuser can rename languages.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
Name of a language
.TP
\fB\fInewname\fB\fR
The new name of the language
.SH "COMPATIBILITY"
.PP
There is no \fBALTER LANGUAGE\fR statement in the SQL
standard.
.SH "SEE ALSO"
CREATE LANGUAGE [\fBcreate_language\fR(l)], DROP LANGUAGE [\fBdrop_language\fR(l)]
