.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "LOAD" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
LOAD \- load or reload a shared library file

.SH SYNOPSIS
.sp
.nf
LOAD '\fIfilename\fR'
.sp
.fi
.SH "DESCRIPTION"
.PP
This command loads a shared library file into the PostgreSQL
server's address space. If the file had been loaded previously,
it is first unloaded. This command is primarily useful to unload
and reload a shared library file that has been changed since the
server first loaded it. To make use of the shared library,
function(s) in it need to be declared using the CREATE FUNCTION [\fBcreate_function\fR(l)]
command.
.PP
The file name is specified in the same way as for shared library
names in CREATE FUNCTION [\fBcreate_function\fR(l)]; in particular, one
may rely on a search path and automatic addition of the system's standard
shared library file name extension. See [XRef to XFUNC] for
more information on this topic.
.SH "COMPATIBILITY"
.PP
\fBLOAD\fR is a PostgreSQL
extension.
.SH "SEE ALSO"
.PP
CREATE FUNCTION [\fBcreate_function\fR(l)]
