.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_ON_CONNECTION_LOSS" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_on_connection_loss \- set or change a callback for unexpected connection loss

.SH SYNOPSIS
.sp
.nf
pg_on_connection_loss \fIconn\fR [\fIcallbackCommand\fR]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_on_connection_loss\fR creates, changes, or
cancels a request to execute a callback command if an unexpected
loss of connection to the database occurs. With a
\fIcallbackCommand\fR parameter, the request is
established, or the command string of an already existing request
is replaced. With no \fIcallbackCommand\fR parameter, a
prior request is canceled.
.PP
The callback command string is executed from the Tcl idle loop.
That is the normal idle state of an application written with Tk.
In non-Tk Tcl shells, you can execute \fBupdate\fR
or \fBvwait\fR to cause the idle loop to be entered.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle to watch for connection losses.
.TP
\fB\fIcallbackCommand\fB\fR
If present, provides the command string to execute when
connection loss is detected.
.SH "RETURN VALUE"
.PP
None
