.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_CONNDEFAULTS" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_conndefaults \- get connection options and their defaults

.SH SYNOPSIS
.sp
.nf
pg_conndefaults
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_conndefaults\fR returns information about the
connection options available in \fBpg_connect
-conninfo\fR and the current default value for each option.
.SH "ARGUMENTS"
.PP
None
.SH "RETURN VALUE"
.PP
The result is a list describing the possible connection options and
their current default values. Each entry in the list is a sublist
of the format:
.sp
.nf
{optname label dispchar dispsize value}
.sp
.fi
where the \fIoptname\fR is usable as an option in
\fBpg_connect -conninfo\fR.
