.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_pfree" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_pfree \- free memory in the upper executor context

.SH SYNOPSIS
.sp
.nf
void SPI_pfree(void * \fIpointer\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_pfree\fR frees memory previously allocated
using \fBSPI_palloc\fR or
\fBSPI_repalloc\fR.
.PP
This function is no longer different from plain
\fBpfree\fR. It's kept just for backward
compatibility of existing code.
.SH "ARGUMENTS"
.TP
\fBvoid * \fIpointer\fB\fR
pointer to existing storage to free
