.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_cursor_fetch" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_cursor_fetch \- fetch some rows from a cursor

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_fetch(Portal \fIportal\fR, bool \fIforward\fR, int \fIcount\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_cursor_fetch\fR fetches some rows from a
cursor. This is equivalent to the SQL command \fBFETCH\fR.
.SH "ARGUMENTS"
.TP
\fBPortal \fIportal\fB\fR
portal containing the cursor
.TP
\fBbool \fIforward\fB\fR
true for fetch forward, false for fetch backward
.TP
\fBint \fIcount\fB\fR
maximum number of rows to fetch
.SH "RETURN VALUE"
.PP
SPI_processed and
SPI_tuptable are set as in
\fBSPI_exec\fR if successful.
