.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ROLLBACK" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ROLLBACK \- abort the current transaction

.SH SYNOPSIS
.sp
.nf
ROLLBACK [ WORK | TRANSACTION ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBROLLBACK\fR rolls back the current transaction and causes
all the updates made by the transaction to be discarded.
.SH "PARAMETERS"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
Optional key words. They have no effect.
.SH "NOTES"
.PP
Use COMMIT [\fBcommit\fR(l)] to
successfully terminate a transaction.
.PP
Issuing \fBROLLBACK\fR when not inside a transaction does
no harm, but it will provoke a warning message.
.SH "EXAMPLES"
.PP
To abort all changes:
.sp
.nf
ROLLBACK;
.sp
.fi
.SH "COMPATIBILITY"
.PP
The SQL standard only specifies the two forms
ROLLBACK and ROLLBACK
WORK. Otherwise, this command is fully conforming.
.SH "SEE ALSO"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)]
