.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_copytupleintoslot" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_copytupleintoslot \- make a copy of a row and descriptor in the upper executor context

.SH SYNOPSIS
.sp
.nf
TupleTableSlot * SPI_copytupleintoslot(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_copytupleintoslot\fR makes a copy of a row in
the upper executor context, returning it in the form of a filled-in
\fBTupleTableSlot\fR structure.
.SH "ARGUMENTS"
.TP
\fBHeapTuple \fIrow\fB\fR
row to be copied
.TP
\fBTupleDesc \fIrowdesc\fB\fR
row descriptor to be copied
.SH "RETURN VALUE"
.PP
\fBTupleTableSlot\fR containing the copied row and
descriptor; \fBNULL\fR only if
\fIrow\fR or \fIrowdesc\fR are
\fBNULL\fR
