.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_gettypeid" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_gettypeid \- return the data type OID of the specified column

.SH SYNOPSIS
.sp
.nf
Oid SPI_gettypeid(TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_gettypeid\fR returns the
OID of the data type of the specified column.
.SH "ARGUMENTS"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
input row description
.TP
\fBint \fIcolnumber\fB\fR
column number (count starts at 1)
.SH "RETURN VALUE"
.PP
The OID of the data type of the specified column
or \fBInvalidOid\fR on error. On error,
SPI_result is set to
\fBSPI_ERROR_NOATTRIBUTE\fR.
