.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_cursor_close" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_cursor_close \- close a cursor

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_close(Portal \fIportal\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_cursor_close\fR closes a previously created
cursor and releases its portal storage.
.PP
All open cursors are closed automatically at the end of a
transaction. \fBSPI_cursor_close\fR need only be
invoked if it is desirable to release resources sooner.
.SH "ARGUMENTS"
.TP
\fBPortal \fIportal\fB\fR
portal containing the cursor
