.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "DEALLOCATE" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
DEALLOCATE \- deallocate a prepared statement

.SH SYNOPSIS
.sp
.nf
DEALLOCATE [ PREPARE ] \fIplan_name\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBDEALLOCATE\fR is used to deallocate a previously
prepared SQL statement. If you do not explicitly deallocate a
prepared statement, it is deallocated when the session ends.
.PP
For more information on prepared statements, see PREPARE [\fBprepare\fR(l)].
.SH "PARAMETERS"
.TP
\fBPREPARE\fR
This key word is ignored.
.TP
\fB\fIplan_name\fB\fR
The name of the prepared statement to deallocate.
.SH "COMPATIBILITY"
.PP
The SQL standard includes a \fBDEALLOCATE\fR
statement, but it is only for use in embedded SQL.
