.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "START TRANSACTION" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
START TRANSACTION \- start a transaction block

.SH SYNOPSIS
.sp
.nf
START TRANSACTION [ ISOLATION LEVEL { READ COMMITTED | SERIALIZABLE } ] [ READ WRITE | READ ONLY ]
.sp
.fi
.SH "DESCRIPTION"
.PP
This command begins a new transaction. If the isolation level or
read/write mode is specified, the new transaction has those
characteristics, as if SET TRANSACTION [\fBset_transaction\fR(l)] was executed. In all other
respects, the behavior of this command is identical to the BEGIN [\fBbegin\fR(l)] command.
.SH "PARAMETERS"
.PP
See under SET TRANSACTION [\fBset_transaction\fR(l)] about the meaning of the
parameters.
.SH "COMPATIBILITY"
.PP
This command conforms to the SQL standard; but see also the
compatibility section of SET TRANSACTION [\fBset_transaction\fR(l)].
.SH "SEE ALSO"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)], SET TRANSACTION [\fBset_transaction\fR(l)]
