.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_UNLINK" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_unlink \- delete a large object

.SH SYNOPSIS
.sp
.nf
pg_lo_unlink \fIconn\fR \fIloid\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_unlink\fR deletes the specified large
object.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which the large object
exists.
.TP
\fB\fIloid\fB\fR
The OID of the large object.
.SH "RETURN VALUE"
.PP
None
