.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_CREAT" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_creat \- create a large object

.SH SYNOPSIS
.sp
.nf
pg_lo_creat \fIconn\fR \fImode\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_creat\fR creates a large object.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which to create the large
object.
.TP
\fB\fImode\fB\fR
The access mode for the large object. It can be any or'ing
together of INV_READ and INV_WRITE. The
``or'' operator is |. For
example:
.sp
.nf
[pg_lo_creat $conn "INV_READ|INV_WRITE"]
.sp
.fi
.SH "RETURN VALUE"
.PP
The OID of the large object created.
