.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ALTER CONVERSION" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ALTER CONVERSION \- change the definition of a conversion

.SH SYNOPSIS
.sp
.nf
ALTER CONVERSION \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBALTER CONVERSION\fR changes the definition of a
conversion. The only currently available functionality is to rename the
conversion.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name (optionally schema-qualified) of an existing conversion.
.TP
\fB\fInewname\fB\fR
The new name of the conversion.
.SH "EXAMPLES"
.PP
To rename the conversion iso_8859_1_to_utf_8 to
latin1_to_unicode:
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf_8 RENAME TO latin1_to_unicode;
.sp
.fi
.SH "COMPATIBILITY"
.PP
There is no \fBALTER CONVERSION\fR statement in the SQL
standard.
.SH "SEE ALSO"
CREATE CONVERSION [\fBcreate_conversion\fR(l)], DROP CONVERSION [\fBdrop_conversion\fR(l)]
