.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "DROP RULE" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
DROP RULE \- remove a rewrite rule

.SH SYNOPSIS
.sp
.nf
DROP RULE \fIname\fR ON \fIrelation\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBDROP RULE\fR drops a rewrite rule.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name of the rule to drop.
.TP
\fB\fIrelation\fB\fR
The name (optionally schema-qualified) of the table or view that
the rule applies to.
.TP
\fBCASCADE\fR
Automatically drop objects that depend on the rule.
.TP
\fBRESTRICT\fR
Refuse to drop the rule if any objects depend on it. This is
the default.
.SH "EXAMPLES"
.PP
To drop the rewrite rule newrule:
.sp
.nf
DROP RULE newrule ON mytable;
.sp
.fi
.SH "COMPATIBILITY"
.PP
There is no \fBDROP RULE\fR statement in the SQL standard.
.SH "SEE ALSO"
CREATE RULE [\fBcreate_rule\fR(l)]
