.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_freetuptable" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_freetuptable \- free a row set created by SPI_exec or a similar function

.SH SYNOPSIS
.sp
.nf
void SPI_freetuptable(SPITupleTable * \fItuptable\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_freetuptable\fR frees a row set created by a
prior SPI command execution function, such as
\fBSPI_exec\fR. Therefore, this function is usually called
with the global variable SPI_tupletable as
argument.
.PP
This function is useful if a SPI procedure needs to execute
multiple commands and does not want to keep the results of earlier
commands around until it ends. Note that any unfreed row sets will
be freed anyway at \fBSPI_finish\fR.
.SH "ARGUMENTS"
.TP
\fBSPITupleTable * \fItuptable\fB\fR
pointer to row set to free
