.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_repalloc" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_repalloc \- reallocate memory in the upper executor context

.SH SYNOPSIS
.sp
.nf
void * SPI_repalloc(void * \fIpointer\fR, Size \fIsize\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_repalloc\fR changes the size of a memory
segment previously allocated using \fBSPI_palloc\fR.
.PP
This function is no longer different from plain
\fBrepalloc\fR. It's kept just for backward
compatibility of existing code.
.SH "ARGUMENTS"
.TP
\fBvoid * \fIpointer\fB\fR
pointer to existing storage to change
.TP
\fBSize \fIsize\fB\fR
size in bytes of storage to allocate
.SH "RETURN VALUE"
.PP
pointer to new storage space of specified size with the contents
copied from the existing area
