.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_getrelname" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_getrelname \- return the name of the specified relation

.SH SYNOPSIS
.sp
.nf
char * SPI_getrelname(Relation \fIrel\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_getrelname\fR returns the name of the
specified relation. (You can use \fBpfree\fR to
release the copy of the name when you don't need it anymore.)
.SH "ARGUMENTS"
.TP
\fBRelation \fIrel\fB\fR
input relation
.SH "RETURN VALUE"
.PP
The name of the specified relation.
