.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ALTER TRIGGER" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ALTER TRIGGER \- change the definition of a trigger

.SH SYNOPSIS
.sp
.nf
ALTER TRIGGER \fIname\fR ON \fItable\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBALTER TRIGGER\fR changes properties of an existing
trigger. The RENAME clause changes the name of
the given trigger without otherwise changing the trigger
definition.
.PP
You must own the table on which the trigger acts to be allowed to change its properties.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name of an existing trigger to alter.
.TP
\fB\fItable\fB\fR
The name of the table on which this trigger acts.
.TP
\fB\fInewname\fB\fR
The new name for the trigger.
.SH "EXAMPLES"
.PP
To rename an existing trigger:
.sp
.nf
ALTER TRIGGER emp_stamp ON emp RENAME TO emp_track_chgs;
.sp
.fi
.SH "COMPATIBILITY"
.PP
\fBALTER TRIGGER\fR is a PostgreSQL
extension of the SQL standard.
