.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_getvalue" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_getvalue \- return the string value of the specified column

.SH SYNOPSIS
.sp
.nf
char * SPI_getvalue(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_getvalue\fR returns the string representation
of the value of the specified column.
.PP
The result is returned in memory allocated using
\fBpalloc\fR. (You can use
\fBpfree\fR to release the memory when you don't
need it anymore.)
.SH "ARGUMENTS"
.TP
\fBHeapTuple \fIrow\fB\fR
input row to be examined
.TP
\fBTupleDesc \fIrowdesc\fB\fR
input row description
.TP
\fBint \fIcolnumber\fB\fR
column number (count starts at 1)
.SH "RETURN VALUE"
.PP
Column value, or \fBNULL\fR if the column is null,
\fIcolnumber\fR is out of range
(SPI_result is set to
\fBSPI_ERROR_NOATTRIBUTE\fR), or no no output function
available (SPI_result is set to
\fBSPI_ERROR_NOOUTFUNC\fR).
