.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "DROP SEQUENCE" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
DROP SEQUENCE \- remove a sequence

.SH SYNOPSIS
.sp
.nf
DROP SEQUENCE \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBDROP SEQUENCE\fR removes sequence number generators.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name (optionally schema-qualified) of a sequence.
.TP
\fBCASCADE\fR
Automatically drop objects that depend on the sequence.
.TP
\fBRESTRICT\fR
Refuse to drop the sequence if any objects depend on it. This
is the default.
.SH "EXAMPLES"
.PP
To remove the sequence serial:
.sp
.nf
DROP SEQUENCE serial;
.sp
.fi
.SH "COMPATIBILITY"
.PP
There is no \fBDROP SEQUENCE\fR statement in the SQL standard.
.SH "SEE ALSO"
CREATE SEQUENCE [\fBcreate_sequence\fR(l)]
