.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_getbinval" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_getbinval \- return the binary value of the specified column

.SH SYNOPSIS
.sp
.nf
Datum SPI_getbinval(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR, bool * \fIisnull\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_getbinval\fR returns the value of the
specified column in the internal form (as type \fBDatum\fR).
.PP
This function does not allocate new space for the datum. In the
case of a pass-by-reference data type, the return value will be a
pointer into the passed row.
.SH "ARGUMENTS"
.TP
\fBHeapTuple \fIrow\fB\fR
input row to be examined
.TP
\fBTupleDesc \fIrowdesc\fB\fR
input row description
.TP
\fBint \fIcolnumber\fB\fR
column number (count starts at 1)
.TP
\fBbool * \fIisnull\fB\fR
flag for a null value in the column
.SH "RETURN VALUE"
.PP
The binary value of the column is returned. The variable pointed
to by \fIisnull\fR is set to true if the column is
null, else to false.
.PP
SPI_result is set to
\fBSPI_ERROR_NOATTRIBUTE\fR on error.
