.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "CHECKPOINT" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
CHECKPOINT \- force a transaction log checkpoint

.SH SYNOPSIS
.sp
.nf
CHECKPOINT
.sp
.fi
.SH "DESCRIPTION"
.PP
Write-Ahead Logging (WAL) puts a checkpoint in the transaction log
every so often. (To adjust the automatic checkpoint interval, see
the run-time
configuration options checkpoint_segments
and checkpoint_timeout.)
The \fBCHECKPOINT\fR command forces an immediate checkpoint
when the command is issued, without waiting for a scheduled checkpoint.
.PP
A checkpoint is a point in the transaction log sequence at which
all data files have been updated to reflect the information in the
log. All data files will be flushed to disk. Refer to the
[XRef to WAL] for more information about the WAL system.
.PP
Only superusers may call \fBCHECKPOINT\fR. The command is
not intended for use during normal operation.
.SH "COMPATIBILITY"
.PP
The \fBCHECKPOINT\fR command is a
PostgreSQL language extension.
