.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ABORT" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ABORT \- abort the current transaction

.SH SYNOPSIS
.sp
.nf
ABORT [ WORK | TRANSACTION ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBABORT\fR rolls back the current transaction and causes
all the updates made by the transaction to be discarded. 
This command is identical
in behavior to the standard SQL command
ROLLBACK [\fBrollback\fR(l)],
and is present only for historical reasons.
.SH "PARAMETERS"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
Optional key words. They have no effect.
.SH "NOTES"
.PP
Use COMMIT [\fBcommit\fR(l)] to
successfully terminate a transaction.
.PP
Issuing \fBABORT\fR when not inside a transaction does
no harm, but it will provoke a warning message.
.SH "EXAMPLES"
.PP
To abort all changes:
.sp
.nf
ABORT;
.sp
.fi
.SH "COMPATIBILITY"
.PP
This command is a PostgreSQL extension
present for historical reasons. \fBROLLBACK\fR is the
equivalent standard SQL command.
.SH "SEE ALSO"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)]
