.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_gettype" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_gettype \- return the data type name of the specified column

.SH SYNOPSIS
.sp
.nf
char * SPI_gettype(TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_gettype\fR returns the data type name of the
specified column. (You can use \fBpfree\fR to
release the copy of the name when you don't need it anymore.)
.SH "ARGUMENTS"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
input row description
.TP
\fBint \fIcolnumber\fB\fR
column number (count starts at 1)
.SH "RETURN VALUE"
.PP
The data type name of the specified column, or
\fBNULL\fR on error. SPI_result is
set to \fBSPI_ERROR_NOATTRIBUTE\fR on error.
