.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_cursor_find" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_cursor_find \- find an existing cursor by name

.SH SYNOPSIS
.sp
.nf
Portal SPI_cursor_find(const char * \fIname\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_cursor_find\fR finds an existing portal by
name. This is primarily useful to resolve a cursor name returned
as text by some other function.
.SH "ARGUMENTS"
.TP
\fBconst char * \fIname\fB\fR
name of the portal
.SH "RETURN VALUE"
.PP
pointer to the portal with the specified name, or
\fBNULL\fR if none was found
