.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_freetuple" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_freetuple \- frees a row allocated in the upper executor context

.SH SYNOPSIS
.sp
.nf
void SPI_freetuple(HeapTuple \fIrow\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_freetuple\fR frees a row previously allocated
in the upper executor context.
.PP
This function is no longer different from plain
\fBheap_freetuple\fR. It's kept just for backward
compatibility of existing code.
.SH "ARGUMENTS"
.TP
\fBHeapTuple \fIrow\fB\fR
row to free
