.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_cursor_move" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_cursor_move \- move a cursor

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_move(Portal \fIportal\fR, bool \fIforward\fR, int \fIcount\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_cursor_move\fR skips over some number of rows
in a cursor. This is equivalent to the SQL command
\fBMOVE\fR.
.SH "ARGUMENTS"
.TP
\fBPortal \fIportal\fB\fR
portal containing the cursor
.TP
\fBbool \fIforward\fB\fR
true for move forward, false for move backward
.TP
\fBint \fIcount\fB\fR
maximum number of rows to move
