.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_IMPORT" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_import \- import a large object from a file

.SH SYNOPSIS
.sp
.nf
pg_lo_import \fIconn\fR \fIfilename\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_import\fR reads the specified file and
places the contents into a new large object.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which to create the large
object.
.TP
\fB\fIfilename\fB\fR
Specified the file from which to import the data.
.SH "RETURN VALUE"
.PP
The OID of the large object created.
.SH "NOTES"
.PP
\fBpg_lo_import\fR must be called within a
\fBBEGIN\fR/\fBCOMMIT\fR transaction block.
