.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "DROP TYPE" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
DROP TYPE \- remove a data type

.SH SYNOPSIS
.sp
.nf
DROP TYPE \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBDROP TYPE\fR will remove a user-defined data type.
Only the owner of a type can remove it.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name (optionally schema-qualified) of the data type to remove.
.TP
\fBCASCADE\fR
Automatically drop objects that depend on the type (such as
table columns, functions, operators).
.TP
\fBRESTRICT\fR
Refuse to drop the type if any objects depend on it. This is
the default.
.SH "EXAMPLES"
.PP
To remove the data type \fBbox\fR:
.sp
.nf
DROP TYPE box;
.sp
.fi
.SH "COMPATIBILITY"
.PP
This command is similar to the corresponding command in the SQL
standard, but note that the \fBCREATE TYPE\fR command
and the data type extension mechanisms in
PostgreSQL differ from the SQL standard.
.SH "SEE ALSO"
CREATE TYPE [\fBcreate_type\fR(l)]
