.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_freeplan" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_freeplan \- free a previously saved plan

.SH SYNOPSIS
.sp
.nf
int SPI_freeplan(void *\fIplan\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_freeplan\fR releases a command execution plan
previously returned by \fBSPI_prepare\fR or saved by
\fBSPI_saveplan\fR.
.SH "ARGUMENTS"
.TP
\fBvoid * \fIplan\fB\fR
pointer to plan to free
.SH "RETURN VALUE"
.PP
\fBSPI_ERROR_ARGUMENT\fR if \fIplan\fR
is \fBNULL\fR.
