.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "CREATE CONSTRAINT TRIGGER" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
CREATE CONSTRAINT TRIGGER \- define a new constraint trigger

.SH SYNOPSIS
.sp
.nf
CREATE CONSTRAINT TRIGGER \fIname\fR
    AFTER \fIevents\fR ON
    \fItablename\fR \fIconstraint\fR \fIattributes\fR
    FOR EACH ROW EXECUTE PROCEDURE \fIfuncname\fR ( \fIargs\fR )
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBCREATE CONSTRAINT TRIGGER\fR is used within
\fBCREATE TABLE\fR/\fBALTER TABLE\fR and by
\fBpg_dump\fR to create the special triggers for
referential integrity.
It is not intended for general use.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name of the constraint trigger.
.TP
\fB\fIevents\fB\fR
The event categories for which this trigger should be fired.
.TP
\fB\fItablename\fB\fR
The name (possibly schema-qualified) of the table in which
the triggering events occur.
.TP
\fB\fIconstraint\fB\fR
Actual constraint specification.
.TP
\fB\fIattributes\fB\fR
The constraint attributes.
.TP
\fB\fIfuncname\fB(\fIargs\fB)\fR
The function to call as part of the trigger processing.
