.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "DROP DOMAIN" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
DROP DOMAIN \- remove a domain

.SH SYNOPSIS
.sp
.nf
DROP DOMAIN \fIname\fR [, ...]  [ CASCADE | RESTRICT ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBDROP DOMAIN\fR will remove a domain. Only the
owner of a domain can remove it.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name (optionally schema-qualified) of an existing domain.
.TP
\fBCASCADE\fR
Automatically drop objects that depend on the domain (such as
table columns).
.TP
\fBRESTRICT\fR
Refuse to drop the domain if any objects depend on it. This is
the default.
.SH "EXAMPLES"
.PP
To remove the domain \fBbox\fR:
.sp
.nf
DROP DOMAIN box;
.sp
.fi
.SH "COMPATIBILITY"
.PP
This command conforms to the SQL standard.
.SH "SEE ALSO"
CREATE DOMAIN [\fBcreate_domain\fR(l)]
