.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "RESET" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
RESET \- restore the value of a run-time parameter to the default value

.SH SYNOPSIS
.sp
.nf
RESET \fIname\fR
RESET ALL
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBRESET\fR restores run-time parameters to their
default values. \fBRESET\fR is an alternative
spelling for
.sp
.nf
SET \fIparameter\fR TO DEFAULT
.sp
.fi
Refer to SET [\fBset\fR(l)] for
details.
.PP
The default value is defined as the value that the parameter would
have had, had no \fBSET\fR ever been issued for it in the
current session. The actual source of this value might be a
compiled-in default, the configuration file, command-line options,
or per-database or per-user default settings. See [XRef to RUNTIME-CONFIG] for details.
.PP
See the \fBSET\fR reference page for details on the
transaction behavior of \fBRESET\fR.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name of a run-time parameter. See SET [\fBset\fR(l)] for a list.
.TP
\fBALL\fR
Resets all settable run-time parameters to default values.
.SH "EXAMPLES"
.PP
Set DATESTYLE to its default value:
.sp
.nf
RESET datestyle;
.sp
.fi
.PP
Set GEQO to its default value:
.sp
.nf
RESET geqo;
.sp
.fi
.SH "COMPATIBILITY"
.PP
\fBRESET\fR is a PostgreSQL extension.
