.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "ALTER OPERATOR CLASS" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
ALTER OPERATOR CLASS \- change the definition of an operator class

.SH SYNOPSIS
.sp
.nf
ALTER OPERATOR CLASS \fIname\fR USING \fIindex_method\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBALTER OPERATOR CLASS\fR changes the definition of
an operator class. The only functionality is to rename the
operator class.
.SH "PARAMETERS"
.TP
\fB\fIname\fB\fR
The name (optionally schema-qualified) of an existing operator
class.
.TP
\fB\fIindex_method\fB\fR
The name of the index method this operator class is for.
.TP
\fB\fInewname\fB\fR
The new name of the operator class.
.SH "COMPATIBILITY"
.PP
There is no \fBALTER OPERATOR CLASS\fR statement in
the SQL standard.
.SH "SEE ALSO"
CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)], DROP OPERATOR CLASS [\fBdrop_operator_class\fR(l)]
