.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "END" "" "2007-09-16" "SQL - Language Statements" "SQL Commands"
.SH NAME
END \- commit the current transaction

.SH SYNOPSIS
.sp
.nf
END [ WORK | TRANSACTION ]
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBEND\fR commits the current transaction. All changes
made by the transaction become visible to others and are guaranteed
to be durable if a crash occurs. This command is a
PostgreSQL extension
that is equivalent to COMMIT [\fBcommit\fR(l)].
.SH "PARAMETERS"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
Optional key words. They have no effect.
.SH "NOTES"
.PP
Use ROLLBACK [\fBrollback\fR(l)] to
abort a transaction.
.PP
Issuing \fBEND\fR when not inside a transaction does
no harm, but it will provoke a warning message.
.SH "EXAMPLES"
.PP
To commit the current transaction and make all changes permanent:
.sp
.nf
END;
.sp
.fi
.SH "COMPATIBILITY"
.PP
\fBEND\fR is a PostgreSQL
extension that provides functionality equivalent to COMMIT [\fBcommit\fR(l)], which is
specified in the SQL standard.
.SH "SEE ALSO"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)]
