.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_copytuple" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_copytuple \- make a copy of a row in the upper executor context

.SH SYNOPSIS
.sp
.nf
HeapTuple SPI_copytuple(HeapTuple \fIrow\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_copytuple\fR makes a copy of a row in the
upper executor context.
.SH "ARGUMENTS"
.TP
\fBHeapTuple \fIrow\fB\fR
row to be copied
.SH "RETURN VALUE"
.PP
the copied row; \fBNULL\fR only if
\fItuple\fR is \fBNULL\fR
