.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_OPEN" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_open \- open a large object

.SH SYNOPSIS
.sp
.nf
pg_lo_open \fIconn\fR \fIloid\fR \fImode\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_open\fR opens a large object.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which the large object
exists.
.TP
\fB\fIloid\fB\fR
The OID of the large object.
.TP
\fB\fImode\fB\fR
Specifies the access mode for the large object. Mode can be
either r, w, or rw.
.SH "RETURN VALUE"
.PP
A descriptor for use in later large-object commands.
