.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "SPI_palloc" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
SPI_palloc \- allocate memory in the upper executor context

.SH SYNOPSIS
.sp
.nf
void * SPI_palloc(Size \fIsize\fR)
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBSPI_palloc\fR allocates memory in the upper
executor context.
.SH "ARGUMENTS"
.TP
\fBSize \fIsize\fB\fR
size in bytes of storage to allocate
.SH "RETURN VALUE"
.PP
pointer to new storage space of the specified size
