.\\" auto-generated by docbook2man-spec $Revision: 1.1.1.1 $
.TH "PG_LO_LSEEK" "" "2007-09-16" "" "PostgreSQL 7.4.18 Documentation"
.SH NAME
pg_lo_lseek \- seek to a position of a large object

.SH SYNOPSIS
.sp
.nf
pg_lo_lseek \fIconn\fR \fIdescriptor\fR \fIoffset\fR \fIwhence\fR
.sp
.fi
.SH "DESCRIPTION"
.PP
\fBpg_lo_lseek\fR moves the current read/write
position to \fIoffset\fR bytes from the position
specified by \fIwhence\fR.
.SH "ARGUMENTS"
.TP
\fB\fIconn\fB\fR
The handle of a connection to the database in which the large object
exists.
.TP
\fB\fIdescriptor\fB\fR
A descriptor for the large object from
\fBpg_lo_open\fR.
.TP
\fB\fIoffset\fB\fR
The new seek position in bytes.
.TP
\fB\fIwhence\fB\fR
Specified from where to calculate the new seek position:
SEEK_CUR (from current position),
SEEK_END (from end), or SEEK_SET (from
start).
.SH "RETURN VALUE"
.PP
None
